==> zio-aws-elasticloadbalancingv2_2.12-5.17.130.6-sources.jar: zio/aws/elasticloadbalancingv2/model/DescribeTagsResponse.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeTagsResponse(
    tagDescriptions: Option[
      Iterable[zio.aws.elasticloadbalancingv2.model.TagDescription]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse = {
    import DescribeTagsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
      .builder()
      .optionallyWith(
        tagDescriptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagDescriptions)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse
      .wrap(buildAwsValue())
}
object DescribeTagsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse =
      zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse(
        tagDescriptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tagDescriptions: Option[
      List[zio.aws.elasticloadbalancingv2.model.TagDescription.ReadOnly]
    ]
    def getTagDescriptions: ZIO[Any, AwsError, List[
      zio.aws.elasticloadbalancingv2.model.TagDescription.ReadOnly
    ]] = AwsError.unwrapOptionField("tagDescriptions", tagDescriptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
  ) extends zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse.ReadOnly {
    override val tagDescriptions: Option[
      List[zio.aws.elasticloadbalancingv2.model.TagDescription.ReadOnly]
    ] = scala
      .Option(impl.tagDescriptions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticloadbalancingv2.model.TagDescription.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
  ): zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticloadbalancingv2_2.12-5.17.265.1-sources.jar: zio/aws/elasticloadbalancingv2/model/DescribeTagsResponse.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeTagsResponse(
    tagDescriptions: Optional[
      Iterable[zio.aws.elasticloadbalancingv2.model.TagDescription]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse = {
    import DescribeTagsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
      .builder()
      .optionallyWith(
        tagDescriptions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagDescriptions)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse
      .wrap(buildAwsValue())
}
object DescribeTagsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse =
      zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse(
        tagDescriptions.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def tagDescriptions: Optional[
      List[zio.aws.elasticloadbalancingv2.model.TagDescription.ReadOnly]
    ]
    def getTagDescriptions: ZIO[Any, AwsError, List[
      zio.aws.elasticloadbalancingv2.model.TagDescription.ReadOnly
    ]] = AwsError.unwrapOptionField("tagDescriptions", tagDescriptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
  ) extends zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse.ReadOnly {
    override val tagDescriptions: Optional[
      List[zio.aws.elasticloadbalancingv2.model.TagDescription.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.tagDescriptions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticloadbalancingv2.model.TagDescription.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.DescribeTagsResponse
  ): zio.aws.elasticloadbalancingv2.model.DescribeTagsResponse.ReadOnly =
    new Wrapper(impl)
}
